Changes
=======

Version 0.4.0 (2018-11-06)
--------------------------

- Aggregates OpenAPI specifications of REANA components.
- Improves AMQP re-connection handling. Switches from ``pika`` to ``kombu``.
- Enhances test suite and increases code coverage.
- Changes license to MIT.

Version 0.3.1 (2018-09-04)
--------------------------

- Adds parameter expansion and validation utilities for parametrised Serial
  workflows.

Version 0.3.0 (2018-08-10)
--------------------------

- Initial public release.
- Provides basic AMQP pub/sub methods for REANA components.
- Utilities for caching used in different REANA components.
- Click formatting helpers.

.. admonition:: Please beware

   Please note that REANA is in an early alpha stage of its development. The
   developer preview releases are meant for early adopters and testers. Please
   don't rely on released versions for any production purposes yet.
